@@ -8,14 +8,13 @@ from rkale.exceptions import ConfigError, DataRootError, DatasetError
 
 @lru_cache()
 def global_configuration():
-    rkale_config_path = Path.home() / ".config/rkale/rkale.conf"
-    if rkale_config_path.exists():
-        return load_configuration(rkale_config_path)
+    global_config_path = Path.home() / ".config/rkale/rkale.conf"
+    if global_config_path.exists():
+        return load_configuration(global_config_path)
     else:
         return dict(
-            data=dict(
-                root=str(Path.home() / "rkale-data"),
-            )
+            data=dict(root=Path.home() / "data"),
+            rclone=dict(flags=["--transfers 32", "--checkers 32"]),
         )
 
 
@@ -72,7 +71,9 @@ def find(name, root):
         if (root / name).exists():
             return root / name
         root = root.parent
-    raise FileNotFoundError(f"Could not find file {name} in path {root} or any of it's parent directories")
+    raise FileNotFoundError(
+        f"Could not find file {name} in path {root} or any of it's parent directories"
+    )
 
 
 def load_configuration(path):
