@@ -1,4 +1,4 @@
-from rkale.config import get_datasets, global_configuration
+from rkale.config import datasets, global_configuration
 from rkale.operations import handle_copy, handle_sync
 
 
@@ -19,7 +19,7 @@ def _apply_to_datasets(func, working_dir=None, force=False, upstream=False):
     data_root = global_config["data"]["root"]
     paths = []
 
-    for dataset in get_datasets(working_dir=working_dir):
+    for dataset in datasets(working_dir=working_dir):
         remote = dataset["remote"]
         if "aliases" in global_config and remote in global_config["aliases"]:
             remote = global_config["aliases"][remote]
